@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //
-// $Id: key.h 5579 2013-11-20 20:54:28Z rafisol $
+// $Id$
 //
 // Copyright (C) 2008-2010  Rafael Ostertag
 //
@@ -114,9 +114,13 @@ namespace YAPET {
             //! Cleanup routine
             void cleanup();
 
+	    EVP_MD_CTX *create_context();
+
+	    void destroy_context(EVP_MD_CTX *context);
+
         public:
             //! Initializes the key
-            Key (const char* password) throw (YAPETException);
+            Key (const char* password);
             Key (const Key& k);
             ~Key();
 
