@@ -1,6 +1,6 @@
 // -*- c++ -*-
 //
-// $Id: partdec.h 5906 2014-01-26 12:44:06Z rafisol $
+// $Id$
 //
 // Copyright (C) 2008-2011, 2013  Rafael Ostertag
 //
@@ -83,17 +83,17 @@ namespace YAPET {
             PartDec();
 
             PartDec (BDBuffer& bd,
-                     const Key& key) throw (YAPETException);
+                     const Key& key);
 
             PartDec (Record<PasswordRecord>& pr,
-                     const Key& key) throw (YAPETException);
+                     const Key& key);
 
             PartDec (const PartDec& pd);
 
             ~PartDec();
 
             void setRecord (Record<PasswordRecord>& pr,
-                            const Key& key) throw (YAPETException);
+                            const Key& key);
             /**
              * @brief Get the encrypted password record.
              *
